#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_CAURND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_CAURND_HPP_INCLUDED

#include <nt2/statistics/include/functions/scalar/caurnd.hpp>

#endif
